# Get started

For a extremely quick start, read this [one minute guide](./one_min_guide.ipynb). Or, learn about how the objects and functions are related to each other [here](./network_of_object.md).

If you have questions about any function, you can always go to [API references](./public_api_reference.md). Or you could checkout the following examples. More example can be found [here](ideal_test.md) and [here](ocean_example.md)

::::{grid} 1 1 1 3
:class-container: text-center
:gutter: 3

:::{grid-item-card}
:link: sciserver_notebooks/IGPwinter
:link-type: doc
:class-header: bg-light

Running Lagrangian particle on regional dataset
^^^

```{image} https://github.com/MaceKuailv/seaduck_sciserver_notebook/blob/master/stable_images/IGP_32_0.png?raw=true
:height: 200
```

:::

:::{grid-item-card}
:link: sciserver_notebooks/LLC4320
:link-type: doc
:class-header: bg-light

Example with complex grid (LLC4320)
^^^

```{image} https://github.com/MaceKuailv/seaduck_sciserver_notebook/blob/master/stable_images/LLC4320Thumbnail.png?raw=true
:height: 200
```

:::

:::{grid-item-card}
:link: sciserver_notebooks/KangerFjord
:link-type: doc
:class-header: bg-light

Interpolation near a fjord in Eastern Greenland
^^^

```{image} https://github.com/MaceKuailv/seaduck_sciserver_notebook/blob/master/stable_images/Fjord_29_0.png?raw=true
:height: 200
```

:::

::::
